@@ -21,10 +21,10 @@ def make_info(document):
     individual_data = from_networkx(G)
     return G, df, individual_data
 
-def predictionsUnique(saved_model_folder, document_to_predict_json,labels_tab):
-    prediction_dataset_folder = getDataForUniquePrediction(document_to_predict_json, saved_model_folder)
+def predictionsUnique(saved_model_folder,saved_prediction_dataset_folder,document_to_predict_json,labels_tab):
+    getDataForUniquePrediction(document_to_predict_json,saved_prediction_dataset_folder)
 
-    predictions_data = load_predictionData(save_fd=prediction_dataset_folder)
+    predictions_data = load_predictionData(save_fd=saved_prediction_dataset_folder)
 
     model = torch.load(saved_model_folder)
 
